/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.harness;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;

public class Configuration
{
    private static final String WINDOW_TITLE = "Gfx test harness";

    private static final String PROPERTIES_FILE_NAME = "gfx_harness.properties";

    private static final int DEFAULT_WINDOW_WIDTH = 1024;
    private static final int DEFAULT_WINDOW_HEIGHT = 768;
    private static final String DEFAULT_REFERENCE_JAVA = "/usr/lib/jvm/java/bin/java";
    private static final String DEFAULT_TESTED_JAVA = "/usr/lib/jvm/java/bin/java";
    private static final String DEFAULT_SAMPLES_DIRECTORY = "samples";
    private static final String DEFAULT_OUTPUT_DIRECTORY = "output";
    private static final String TEST_SOURCES_DIRECTORY = "src/org/gfxtest/testsuites";
    private static final String TEST_CLASSES_DIRECTORY = "test-build/org/gfxtest/testsuites";

    private String referenceJava;
    private String testedJava;
    private boolean verboseCompile;
    private boolean verboseRun;
    private int mainWindowWidth;
    private int mainWindowHeight;
    private String samplesDirectory;
    private String outputDirectory;

    public Configuration()
    {
        this.setDefaultValues();
    }

    private void setDefaultValues()
    {
        this.referenceJava = DEFAULT_REFERENCE_JAVA;
        this.testedJava = DEFAULT_TESTED_JAVA;
        this.verboseCompile = false;
        this.verboseRun = false;
        this.mainWindowWidth = DEFAULT_WINDOW_WIDTH;
        this.mainWindowHeight = DEFAULT_WINDOW_HEIGHT;
        this.samplesDirectory = DEFAULT_SAMPLES_DIRECTORY;
        this.outputDirectory = DEFAULT_OUTPUT_DIRECTORY;
    }

    private void printErrorMessage(Exception e)
    {
        System.err.println("Cannot access configuration file " + e.getMessage());
        e.printStackTrace();
    }

    public boolean readConfiguration()
    {
        boolean result = true;

        // Read properties file.
        Properties properties = new Properties();
        FileInputStream fileInputStream = null;
        try
        {
            fileInputStream = new FileInputStream(PROPERTIES_FILE_NAME);
            properties.load(fileInputStream);
        }
        catch (FileNotFoundException e)
        {
            result = false;
            this.printErrorMessage(e);
            this.setDefaultValues();
        }
        catch (IOException e)
        {
            result = false;
            this.printErrorMessage(e);
            this.setDefaultValues();
        }
        finally
        {
            if (fileInputStream != null)
            {
                try
                {
                    fileInputStream.close();
                }
                catch (IOException e)
                {
                    // TODO Auto-generated catch block
                    e.printStackTrace();
                }
            }
        }
        this.setReferenceJava(properties.getProperty("jre.reference"));
        this.setTestedJava(properties.getProperty("jre.tested"));
        this.setVerboseCompile("true".equals(properties.getProperty("compile.verbose")));
        this.setVerboseRun("true".equals(properties.getProperty("run.verbose")));
        try
        {
            this.setMainWindowWidth(Integer.parseInt(properties.getProperty("mainWindow.width")));
            this.setMainWindowHeight(Integer.parseInt(properties.getProperty("mainWindow.height")));
        }
        catch (NumberFormatException e)
        {
            System.err.println("warning: can't read integer value from property file");
        }
        this.setSamplesDirectory(properties.getProperty("paths.samplesDirectory"));
        this.setOutputDirectory(properties.getProperty("paths.outputDirectory"));
        return result;
    }

    public boolean writeConfiguration()
    {
        boolean result = true;

        // Write properties file.
        Properties properties = new Properties();
        properties.setProperty("jre.reference", this.getReferenceJava());
        properties.setProperty("jre.tested", this.getTestedJava());
        properties.setProperty("compile.verbose", this.isVerboseCompile() ? "true" : "false");
        properties.setProperty("run.verbose", this.isVerboseRun() ? "true" : "false");
        properties.setProperty("mainWindow.width", "" + this.getMainWindowWidth());
        properties.setProperty("mainWindow.height", "" + this.getMainWindowHeight());
        properties.setProperty("paths.samplesDirectory", this.getSamplesDirectory());
        properties.setProperty("paths.outputDirectory", this.getOutputDirectory());
        FileOutputStream fileOutputStream = null;
        try
        {
            fileOutputStream = new FileOutputStream(PROPERTIES_FILE_NAME);
            properties.store(fileOutputStream, null);
        }
        catch (IOException e)
        {
            result = false;
            e.printStackTrace();
        }
        finally
        {
            if (fileOutputStream != null)
            {
                try
                {
                    fileOutputStream.close();
                }
                catch (IOException e)
                {
                    e.printStackTrace();
                }
            }
        }
        return result;
    }

    public String getReferenceJava()
    {
        return this.referenceJava;
    }

    public void setReferenceJava(String referenceJava)
    {
        this.referenceJava = referenceJava;
    }

    public String getTestedJava()
    {
        return this.testedJava;
    }

    public void setTestedJava(String testedJava)
    {
        this.testedJava = testedJava;
    }

    public boolean isVerboseCompile()
    {
        return this.verboseCompile;
    }

    public void setVerboseCompile(boolean verboseCompile)
    {
        this.verboseCompile = verboseCompile;
    }

    public boolean isVerboseRun()
    {
        return this.verboseRun;
    }

    public void setVerboseRun(boolean verboseRun)
    {
        this.verboseRun = verboseRun;
    }

    public int getMainWindowWidth()
    {
        return this.mainWindowWidth;
    }

    public void setMainWindowWidth(int mainWindowWidth)
    {
        this.mainWindowWidth = mainWindowWidth;
    }

    public int getMainWindowHeight()
    {
        return this.mainWindowHeight;
    }

    public void setMainWindowHeight(int mainWindowHeight)
    {
        this.mainWindowHeight = mainWindowHeight;
    }

    public String getSamplesDirectory()
    {
        return this.samplesDirectory;
    }

    public void setSamplesDirectory(String samplesDirectory)
    {
        this.samplesDirectory = samplesDirectory;
    }

    public String getOutputDirectory()
    {
        return this.outputDirectory;
    }

    public void setOutputDirectory(String outputDirectory)
    {
        this.outputDirectory = outputDirectory;
    }

    public static String getTestSourcesDirectory()
    {
        return TEST_SOURCES_DIRECTORY;
    }

    public static String getTestClassesDirectory()
    {
        return TEST_CLASSES_DIRECTORY;
    }

    public static String getWindowTitle()
    {
        return WINDOW_TITLE;
    }
}
