/*
  Java gfx-test framework

   Copyright (C) 2013, 2014  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;
import java.awt.geom.Area;



import org.gfxtest.framework.CommonCAGOperations;
import org.gfxtest.framework.CommonRenderingStyles;
import org.gfxtest.framework.GfxTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test checks the process of creating and rendering new geometric shapes
 * by performing boolean operations on existing ones. This process is often
 * called Constructive area geometry (CAG). Various cases are checked by this
 * test suite.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.AREA)
@RenderStyle(RenderStyles.FILL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class CAGOperationsOnChordAndRectangle extends GfxTest
{

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleUnionStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape
     * is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleIntersectStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape
     * is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleInverseSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using Xor operator.
     * The shape is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleXorStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleUnionWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleIntersectWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleInverseSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using Xor operator.
     * The shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleXorWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleUnionExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape
     * is rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleIntersectExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape
     * is rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleInverseSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using Xor operator.
     * The shape is rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleXorExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleUnionColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape is
     * rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleInverseSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleIntersectColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using XOR operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleXorColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleUnionRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleInverseSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleIntersectRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using XOR operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleXorRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleUnionHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleInverseSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleIntersectHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using XOR operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleXorHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleUnionVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleInverseSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleIntersectVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using XOR operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleXorVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleUnionDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleInverseSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleIntersectDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using XOR operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBigChordRectangleXorDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromBiggerChordAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleUnionStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape
     * is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleInverseSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape
     * is rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleIntersectStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using XOR operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleXorStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleUnionWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleInverseSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleIntersectWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using XOR operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleXorWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleUnionExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleInverseSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleIntersectExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using XOR operator. The shape is
     * rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleXorExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke extra width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using union operator. The shape is
     * rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleUnionColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using subtract operator. The shape is
     * rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using inverse subtract operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleInverseSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using intersect operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleIntersectColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }


    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using XOR operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleXorColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using union operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleUnionRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using subtract operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using inverse subtract operator.
     * The shape is rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleInverseSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using intersect operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleIntersectRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using XOR operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleXorRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using union operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleUnionHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using subtract operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using inverse subtract operator.
     * The shape is rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleInverseSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using intersect operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleIntersectHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using XOR operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleXorHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using union operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleUnionVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using subtract operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using inverse subtract operator.
     * The shape is rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleInverseSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using intersect operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleIntersectVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using XOR operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleXorVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using union operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleUnionDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using subtract operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using inverse subtract operator.
     * The shape is rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleInverseSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using intersect operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleIntersectDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using XOR operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testSmallChordInsideRectangleXorDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromSmallerChordInsideRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleUnionStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleInverseSubtractStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleIntersectStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using XOR operator. The shape is
     * rendered using stroke paint.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleXorStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleUnionWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleInverseSubtractWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleIntersectWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using XOR operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleXorWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using union operator. The shape is
     * rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleUnionExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingUnionOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using subtract operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using inverse subtract operator.
     * The shape is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleInverseSubtractExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingInverseSubtractOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using intersect operator. The shape
     * is rendered using wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleIntersectExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set extra wide stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingIntersectOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from chord and rectangle using XOR operator. The shape is
     * rendered using extra wide stroke.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleXorExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke extra width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingXorOperator(image);
        // draw the area
        graphics2d.draw(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using union operator. The shape is
     * rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleUnionColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using subtract operator. The shape is
     * rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using inverse subtract operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleInverseSubtractColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using intersect operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleIntersectColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using XOR operator.
     * The shape is rendered using color fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleXorColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area using Xor operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using union operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleUnionRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using subtract operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using inverse subtract operator.
     * The shape is rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleInverseSubtractRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using intersect operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleIntersectRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using XOR operator. The shape is
     * rendered using radial gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleXorRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set radial gradient fill
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using union operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleUnionHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using subtract operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using inverse subtract operator.
     * The shape is rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleInverseSubtractHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using intersect operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleIntersectHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using XOR operator. The shape is
     * rendered using horizontal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleXorHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set horizontal gradient fill
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using union operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleUnionVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using subtract operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using inverse subtract operator.
     * The shape is rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleInverseSubtractVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using intersect operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleIntersectVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using XOR operator. The shape is
     * rendered using vertical gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleXorVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set vertical gradient fill
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using union operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleUnionDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using union operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingUnionOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using subtract operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using inverse subtract operator.
     * The shape is rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleInverseSubtractDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using inverse subtract operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingInverseSubtractOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using intersect operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleIntersectDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using intersect operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingIntersectOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Checks the process of creating and rendering new geometric shape
     * constructed from a chord inside a rectangle using XOR operator. The shape is
     * rendered using diagonal gradient fill.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOverlappingChordAndRectangleXorDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // set diagonal gradient fill
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // create area using XOR operator
        Area area = CommonCAGOperations.createAreaFromOverlappingChordAndRectangleUsingXorOperator(image);
        // fill the area
        graphics2d.fill(area);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new CAGOperationsOnChordAndRectangle().runTestSuite(args);
    }

}
